#
# spec file for package apache2-mod_gnutls
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2010 invis-server.org Schotten Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


########################################
# apache macros
########################################
%define modname mod_gnutls
%define name apache2-%{modname}
Name:           apache2-mod_gnutls
Version:        0.8.3
Release:        1.15
Summary:        Apache2 Module GnuTLS
License:        Apache-2.0
Group:          Productivity/Networking/Web/Utilities
URL:            https://mod.gnutls.org/
Source0:        https://mod.gnutls.org/downloads/mod_gnutls-%{version}.tar.bz2
Source2:        mod_gnutls.conf
Source3:        README.invis
Source4:        mod_gnutls.html
Source100:      test-server.crt
Source101:      test-server.key
BuildRequires:  apache-rpm-macros
BuildRequires:  apache2-devel
BuildRequires:  autoconf
BuildRequires:  automake
# for testing
BuildRequires:  curl
BuildRequires:  libgnutls-devel >= 3.3.0
BuildRequires:  libmemcache-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
Requires:       %{apache_mmn}
Requires:       %{apache_suse_maintenance_mmn}
Requires:       apache2

%description
mod_gnutls uses the GnuTLS library to provide SSL 3.0, TLS 1.0
and TLS 1.1 encryption for Apache HTTPD.
It is similar to mod_ssl in purpose, but does not use OpenSSL.
It supports SNI, so it can be used to encrypt multiple name based
virtual hosts, each with its own certificate.

To load the module into Apache, run the command "a2enmod gnutls" as root.

To learn about the configuration, refer to
%{_docdir}/apache2-mod_gnutls/README.

%prep
%setup -q -n %{modname}-%{version}

%build
autoreconf -fiv
%configure --with-apxs=%{apache_apxs}

# RPM_OPT_FLAGS come from apxs
make %{?_smp_mflags} OPT="$(%{apache_apxs} -q CFLAGS)"

%install
install -Dpm 755 src/.libs/%{modname}.so %{buildroot}%{apache_libexecdir}/%{modname}.so 
install -Dpm 644 %{SOURCE2} %{buildroot}%{apache_sysconfdir}/%{modname}.conf
cp -a %{SOURCE3} README.invis
cp -a %{SOURCE4} mod_gnutls.html

%check
set +x
mkdir -p %{apache_test_module_dir}
# install test certificate
cp %{SOURCE100} %{apache_test_module_dir}
cp %{SOURCE101} %{apache_test_module_dir}
# configuration
cat << EOF > %{apache_test_module_dir}/%{modname}-test.conf
GnuTLSEnable on
GnuTLSPriorities NORMAL:!DHE-RSA:!DHE-DSS:!AES-256-CBC:%COMPAT
GnuTLSCertificateFile %{apache_test_module_dir}/test-server.crt
GnuTLSKeyFile %{apache_test_module_dir}/test-server.key
<Directory %{apache_test_module_dir}/htdocs>
  Require local
</Directory>
EOF
# a test document
mkdir -p %{apache_test_module_dir}/htdocs
cat << EOF > %{apache_test_module_dir}/htdocs/index.html
HTTPS HELLO
EOF
# start httpd test instance
%apache_test_module_start_apache -m gnutls -i %{modname}-test.conf
# get the testing document
%apache_test_module_curl -r https -d /index.html -o %{apache_test_module_dir}/output.txt
# test the document
echo
echo 'Testing /index.html output'
exit_code=0
grep 'HTTPS HELLO' %{apache_test_module_dir}/output.txt || exit_code=1
if [ $exit_code -eq 0 ]; then
  echo 'SUCCESS'
else
  echo 'FAILED, error_log:'
  cat %{apache_test_module_dir}/error_log
fi
echo
# stop httpd test instance
%apache_test_module_stop_apache
set -x
exit $exit_code

%files
%doc LICENSE README* *.html
%config(noreplace) %{apache_sysconfdir}/%{modname}.conf
%attr(755, root, root) %{apache_libexecdir}/%{modname}.so

%changelog
* Wed Dec 20 2017 pgajdos@suse.com
- updated to 0.8.3
  - Use GnuTLS' default DH parameters by default
  - Handle long Server Name Indication data and gracefully ignore
    unknown SNI types
  - Send SNI for proxy connections
  - Deprecate OpenPGP support like GnuTLS did (will be removed
    completely in a future release)
  - Do not announce session ticket support for proxy connections
  - Minor documentation updates (SSL_CLIENT_I_DN, reference for SNI)
  - Bugfix: Use APR_SIZE_T_FMT for portable apr_size_t formatting
  - New: Support for OCSP stapling
  - Bugfix: Access to DBM cache is locked using global mutex
    "gnutls-cache"
  - Bugfix: GnuTLSSessionTickets is now disabled by default as described
    in the handbook
  - Fixed memory leak while checking proxy backend certificate
  - Fixed memory leaks in post_config
  - Safely delete session ticket key (requires GnuTLS >= 3.4)
  - Improved error handling in post_config hook
  - Various handbook updates
  - Internal API documentation can be generated using Doxygen
  - Unused code has been removed (conditionals for GnuTLS 2.x and Apache
    versions before 2.2, internal Lua bytecode structure last used in
    2011).
    certificate authority
  - Sunil Mohan Adapa reported retry loops during session shutdown in
    cleanup_gnutls_session() due to gnutls_bye() incorrectly returning
    GNUTLS_E_INTERRUPTED or GNUTLS_E_AGAIN. Setting the GnuTLS session
    errno in mgs_transport_write() fixes the problem.
  - Import Daniel Kahn Gillmor's patches for GnuPG v2 support from the
    Debian package.
  - Build system improvements that allow VPATH builds and get "make
    distcheck" to work
  - Support SoftHSM 2 for PKCS #11 testing
  - Increase verbosity of test logs
  - Update test suite for compatibility with GnuTLS 3.4, which has
    stricter key usage checks and priorities than 3.3.
  - Write non-HTML output to mod_status reports if AP_STATUS_SHORT is
    set (mod_status sets it for requests with the "auto" parameter, e.g.
    https://localhost/server-status?auto).
  - Register "ssl_is_https" function so the special mod_rewrite variable
    %%{HTTPS} works correctly with mod_gnutls. The new test case for this
    requires Wget or curl. Fixes Debian bug #514005.
  - Support for local Apache drop-in config files in the test suite
    (e.g. to load additional modules needed on Fedora).
  - Try to use markdown to build HTML documentation if pandoc is not
    available.
  - Disable use of flock if it is unavailable or does not support
    timeouts (the latter caused the build to fail on Debian Hurd).
  - New test: Disable TLS 1.0 (regression test for Debian bug #754960).
  - Bugfix: Non-blocking reads in the input filter could lead to a busy
    wait in the gnutls_io_input_read function, causing high load on
    Keep-Alive connections waiting for data, until either more data
    could be received or the connection was closed. The fix is to pass
    EAGAIN/EINTR results up to the input filter so they can be handled
    properly.
  - Close TLS session if the input filter receives EOF (mostly relevant
    for proper termination of proxy connections).
  - Remove dependency on APR Memcache, which is replaced by the newer
    version included in the APR Utility Library (libaprutil).
  - Remove dependency on bc. It was used for floating point arithmetic
    in the test suite, the calculations have been changed to use
    integers and pure bash code.
  - Improved handling of PKCS #11 modules: mod_gnutls now loads either
    modules specified using GnuTLSP11Module, or the system defaults, but
    not both. Thanks to Nikos Mavrogiannopoulos for the report and
    initial patch!
  - Initialize variables to safe defaults during client certificate
    verification. Certain error code paths did not set them, but they
    should never be hit due to config validation. This adds another line
    of defense.
* Tue Mar 14 2017 pgajdos@suse.com
- reverted to 0.7, because 0.8.2 needs gnutls >= 3.3.0 which is
  currently satisfied only by Tumbleweed
* Mon Mar 13 2017 pgajdos@suse.com
- updated to 0.8.2
- fix build with new gnutls
  + apache2-mod_gnutls-no-error-deprecated-declarations.patch
- add a true example in %%check
* Wed Sep  9 2015 pgajdos@suse.com
- test module with %%apache_test_module_load
* Wed Sep  9 2015 pgajdos@suse.com
- updated to 0.7
* Thu Jul 16 2015 pgajdos@suse.com
- Requries: %%{apache_suse_maintenance_mmn}
  This will pull this module to the update (in released distribution)
  when apache maintainer thinks it is good (due api/abi changes).
* Fri Oct 31 2014 pgajdos@suse.com
- call spec-cleaner
- use apache rpm macros
* Fri Sep 27 2013 Mathias.Homann@opensuse.org
- update to 0.6.0 from git
  Fri Nov 26 00:00:00 UTC 2010 - clauded1
- update to version 0.5.9.
* Sun Feb  7 2010 stefan@invis-server.org
- Initial build for SuSE Linux. (Testing State)
